Crate dioxus_storage
source ·Expand description
dioxus_storage
Re-exports
pub use client_storage::set_dir_name;pub use client_storage::set_directory;pub use once_cell;pub use postcard;
Macros
- Set the directory where the storage files are located on non-wasm targets.
Functions
- A persistent storage hook that can be used to store data across application reloads.